'****************************************************************
'*  Name    : Test1_DebounceInt.BAS                             *
'*  Author  : [Alberto Freixanet]                               *
'*  Notice  : Copyright (c) 2016 [AFreixanet]                   *
'*          : All Rights Reserved                               *
'*  Date    : 21/03/2016                                        *
'*  Version : 1.0                                               *
'*  Notes   : testing the Debounce library: DebounceInt.Inc     *
'*  Code powered by the Proton Development Suite Version 3578   *
'****************************************************************
'
' 22/03/2016 version 1.1 
' Added checking the events (falling and rising edges)
'
'-------------------------------------------------------------------------------
'    Include "D:\MyIncFiles\Amicus18_25k20.inc"
    Include "Amicus18_25k20.inc"

'    Include "D:\MyIncFiles\SYS_18Fxxk20.INC"
    Include "SYS_18Fxxk20.INC"
    
'-------------------------------------------------------------------------------
' Uncomment this line to use the oscilloscope to see the interrupt pulses. (only for this demo).
    $define _DebugInterrupt_
    Symbol OutTest LATA.3      ' Out interrupt handler for osciloscope. 
    ' Write yourself a debug code into the Debounce.inc file.
'===============================================================================
    ' All the inputs are in PORTB (All inputs to One PORT only is the best solution for EMC compliance).
    '
    $define RisingEdgeMask  %00001111
    $define FallingEdgeMask %11110000

    ' Declaration of the input virtual PORT.
    $define InputPORT PORTB  
    $define VirtualPORT_IdleState %11111111 
    $define AnselPORT ANSELH

    $define _FallingEdgesDetect_
    $define _RisingEdgesDetect_ 
    
'    Include "D:\MyIncFiles\DebounceInt.inc"
    Include "DebounceInt.inc"

' Definition of the Buttons (Swithes) for the output virtual PORT.
    Dim SW0 As DebounceOut.0
    Dim SW1 As DebounceOut.1    
    Dim SW2 As DebounceOut.2    
    Dim SW3 As DebounceOut.3
    Dim SW4 As DebounceOut.4    
    Dim SW5 As DebounceOut.5    
    Dim SW6 As DebounceOut.6
    Dim SW7 As DebounceOut.7    
'===============================================================================
' Definition of other peripherals
    Symbol LED4 = LATA.3    
'===============================================================================    
MAIN_TEST:
    #ifdef WatchDog_Req
    Clrwdt
    #endif
    DelayMS 200
'-------------------------------------------------------------------------------    
'Init variables
    'For demo 
    Low LED4
'-------------------------------------------------------------------------------
    INTCON2 = %10000000     ' PORTB Pullups disabled
    INTCON3 = 0
    '
    EECON1 = 0              ' Clear all eeprom flags.
    PIR2 = 0
    PIE2 = 0
    IPR2 = 0                    
'
' Declare all digital   
    ADCON0 = 0
    ADCON1 = 15
    ADCON2 = 0    
    CM1CON0 = 0
    CM2CON0 = 0
    CM2CON1 = 0    
'    ANSEL = 0
'    ANSELH = 0
'
' Init the eeprom
    EECON1 = 0
    EEADR = 0
    EEDATA = 0
'
' PORTS
    Output PORTA.3
'-------------------------------------------------------------------------------
STARTING_TEST:
    ' Declare the debounce timing by the user: example 40 => reading the inputs every 40mS.
    ' Stable readings after 40 mS x 4 = 160 mS.
    ' The value must to be a multiple of 4. Example: 4,8,12,16,20,24,28,32,36,40,44,48,52,56, etc...
    '
    DebounceRate(40)
    
    HRSOut "Debounce by interrupt by A. Freixanet", CR
    HRSOut "Debounce 8 Buttons", CR   
    HRSOut CR

    While 1 = 1
        ' Check all buttons pressed.
        If SW0 = 0 Then
            HRSOut "SW0 pressed!", CR    
        EndIf
        If SW1 = 0 Then
            HRSOut "SW1 pressed!", CR    
        EndIf    
        If SW2 = 0 Then
            HRSOut "SW2 pressed!", CR    
        EndIf    
        If SW3 = 0 Then
            HRSOut "SW3 pressed!", CR    
        EndIf    
        If SW4 = 0 Then
            HRSOut "SW4 pressed!", CR    
        EndIf
        If SW5 = 0 Then
            HRSOut "SW5 pressed!", CR    
        EndIf    
        If SW6 = 0 Then
            HRSOut "SW6 pressed!", CR    
        EndIf    
        If SW7 = 0 Then
            HRSOut "SW7 pressed!", CR    
        EndIf     

        ' The events must to be clear (bit by bit) after read by the user in the main code.
        $ifdef _FallingEdgesDetect_
        If FallingEdgeDetectedBits > 0 Then
            If FallingEdgeDetectedBits.0 = 1 Then
                HRSOut "Falling Detect SW0", CR
                FallingEdgeDetectedBits.0 = 0       ' Clear the bit, it is already read.
            EndIf
            If FallingEdgeDetectedBits.1 = 1 Then
                HRSOut "Falling Detect SW1", CR
                FallingEdgeDetectedBits.1 = 0
            EndIf            
            If FallingEdgeDetectedBits.2 = 1 Then
                HRSOut "Falling Detect SW2", CR
                FallingEdgeDetectedBits.2 = 0
            EndIf
            If FallingEdgeDetectedBits.3 = 1 Then
                HRSOut "Falling Detect SW3", CR
                FallingEdgeDetectedBits.3 = 0
            EndIf            
            If FallingEdgeDetectedBits.4 = 1 Then
                HRSOut "Falling Detect SW4", CR
                FallingEdgeDetectedBits.4 = 0
            EndIf            
            If FallingEdgeDetectedBits.5 = 1 Then
                HRSOut "Falling Detect SW5", CR
                FallingEdgeDetectedBits.5 = 0
            EndIf
            If FallingEdgeDetectedBits.6 = 1 Then
                HRSOut "Falling Detect SW6", CR
                FallingEdgeDetectedBits.6 = 0
            EndIf            
            If FallingEdgeDetectedBits.7 = 1 Then
                HRSOut "Falling Detect SW7", CR
                FallingEdgeDetectedBits.7 = 0
            EndIf                                    
        EndIf
        $endif
        $ifdef _RisingEdgesDetect_
        ' The events must to be clear (bit by bit) after read by the user in the main code.
        If RisingEdgeDetectedBits > 0 Then
            If RisingEdgeDetectedBits.0 = 1 Then
                HRSOut "Rise Detect SW0", CR
                RisingEdgeDetectedBits.0 = 0
            EndIf
            If RisingEdgeDetectedBits.1 = 1 Then
                HRSOut "Rise Detect SW1", CR
                RisingEdgeDetectedBits.1 = 0
            EndIf            
            If RisingEdgeDetectedBits.2 = 1 Then
                HRSOut "Rise Detect SW2", CR
                RisingEdgeDetectedBits.2 = 0
            EndIf
            If RisingEdgeDetectedBits.3 = 1 Then
                HRSOut "Rise Detect SW3", CR
                RisingEdgeDetectedBits.3 = 0
            EndIf            
            If RisingEdgeDetectedBits.4 = 1 Then
                HRSOut "Rise Detect SW4", CR
                RisingEdgeDetectedBits.4 = 0
            EndIf            
            If RisingEdgeDetectedBits.5 = 1 Then
                HRSOut "Rise Detect SW5", CR
                RisingEdgeDetectedBits.5 = 0
            EndIf
            If RisingEdgeDetectedBits.6 = 1 Then
                HRSOut "Rise Detect SW6", CR
                RisingEdgeDetectedBits.6 = 0
            EndIf            
            If RisingEdgeDetectedBits.7 = 1 Then
                HRSOut "Rise Detect SW7", CR
                RisingEdgeDetectedBits.7 = 0
            EndIf                                    
        EndIf
        $endif
            
'        DelayMS 50
    Wend
'===============================================================================
    Stop


